<?xml version="1.0" ?><!DOCTYPE TS><TS language="he" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>מציג התמונות של Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>גרסה:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>תמונה</translation>
    </message>
    <message>
        <source>images</source>
        <translation>תמונות</translation>
    </message>
    <message>
        <source>album</source>
        <translation>אלבום</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>אלבומים</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>ניהול הסנכרון</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>סנכרון:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>אלבום חדש</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>ללא שם</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>יובאו לאחרונה</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>המועדף שלי</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>למחוק את האלבום הזה?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>המועדף שלי</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>ציר זמן</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>ללא שם</translation>
    </message>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>מצגת</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שינוי שם</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>העתקה</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>מציג התמונות של Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>תמונות</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>להוסיף את התמונות לאלבום?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>סנכרון ויצירה</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>סנכרון</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>הייצוא הצליח</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>הייצוא נכשל</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>לזרוק תמונות לאשפה?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>פרטי התמונה</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>מסך מלא</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>מצגת</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>הדפסה</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>העתקה</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>הסרה מהאלבום</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>הוספה למועדפים</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>הסרה מהמועדפים</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>הטייה עם כיוון השעון</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>הטייה נגד כיוון השעון</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>הגדרה כתמונת רקע</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>הצגה במנהל הקבצים</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>פרטי התמונה</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>ניתן לסנכרן תיקיות או לגרור ולשחרר תמונות לציר הזמן</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>הוספה לאלבום</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>הוספה לאלבום חדש</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>פתיחת תיקייה</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>אין לך הרשאות לצפות בתמונה</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>סוג</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>מועד השינוי</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>גודל הקובץ</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>מרחב צבע</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>מצב חשיפה</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>תכנית חשיפה</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>זמן חשיפה</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>מבזק</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>צמצם</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>אורך מוקד</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>חשיפה</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>צמצם מרבי</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>White balance</source>
        <translation>איזון לבן</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>פיצוי מבזק</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>דגם המצלמה</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>דגם העדשה</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Millimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Centimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ring</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>בחירת תיקייה</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add folder</source>
        <translation>הוספת תיקייה</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Calculating...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Previous screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>second</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image management</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 images</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manage sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Syncing: </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recent imported</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>